==> vulkan4j-0.1.0-sources.jar: tech/icey/vk4j/datatype/VkPhysicalDeviceFeatures2.java <==
package tech.icey.vk4j.datatype;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.enumtype;
import tech.icey.panama.annotation.nullable;
import tech.icey.panama.annotation.pointer;
import tech.icey.vk4j.enumtype.VkStructureType;

import java.lang.foreign.*;

import static java.lang.foreign.ValueLayout.OfInt;
import static java.lang.foreign.ValueLayout.PathElement;
import static tech.icey.vk4j.enumtype.VkStructureType.VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_FEATURES_2;

/// {@snippet lang=c :
/// typedef struct VkPhysicalDeviceFeatures2 {
///     VkStructureType sType;
///     void* pNext;
///     VkPhysicalDeviceFeatures features;
/// } VkPhysicalDeviceFeatures2;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkPhysicalDeviceFeatures2.html">VkPhysicalDeviceFeatures2</a>
public record VkPhysicalDeviceFeatures2(MemorySegment segment) implements IPointer {
    public VkPhysicalDeviceFeatures2(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_FEATURES_2);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public VkPhysicalDeviceFeatures features() {
        return new VkPhysicalDeviceFeatures(segment.asSlice(OFFSET$features, LAYOUT$features));
    }

    public void features(VkPhysicalDeviceFeatures value) {
        MemorySegment.copy(value.segment(), 0, segment, OFFSET$features, SIZE$features);
    }

    public static VkPhysicalDeviceFeatures2 allocate(Arena arena) {
        return new VkPhysicalDeviceFeatures2(arena.allocate(LAYOUT));
    }

    public static VkPhysicalDeviceFeatures2[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkPhysicalDeviceFeatures2[] ret = new VkPhysicalDeviceFeatures2[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkPhysicalDeviceFeatures2(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkPhysicalDeviceFeatures2 clone(Arena arena, VkPhysicalDeviceFeatures2 src) {
        VkPhysicalDeviceFeatures2 ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkPhysicalDeviceFeatures2[] clone(Arena arena, VkPhysicalDeviceFeatures2[] src) {
        VkPhysicalDeviceFeatures2[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        VkPhysicalDeviceFeatures.LAYOUT.withName("features")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$features = PathElement.groupElement("features");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final StructLayout LAYOUT$features = (StructLayout) LAYOUT.select(PATH$features);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$features = LAYOUT.byteOffset(PATH$features);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$features = LAYOUT$features.byteSize();
}

==> vulkan4j-0.2.0-sources.jar: tech/icey/vk4j/datatype/VkPhysicalDeviceFeatures2.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkPhysicalDeviceFeatures2 {
///     VkStructureType sType;
///     void* pNext;
///     VkPhysicalDeviceFeatures features;
/// } VkPhysicalDeviceFeatures2;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkPhysicalDeviceFeatures2.html">VkPhysicalDeviceFeatures2</a>
public record VkPhysicalDeviceFeatures2(MemorySegment segment) implements IPointer {
    public VkPhysicalDeviceFeatures2(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_FEATURES_2);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public VkPhysicalDeviceFeatures features() {
        return new VkPhysicalDeviceFeatures(segment.asSlice(OFFSET$features, LAYOUT$features));
    }

    public void features(VkPhysicalDeviceFeatures value) {
        MemorySegment.copy(value.segment(), 0, segment, OFFSET$features, SIZE$features);
    }

    public static VkPhysicalDeviceFeatures2 allocate(Arena arena) {
        return new VkPhysicalDeviceFeatures2(arena.allocate(LAYOUT));
    }

    public static VkPhysicalDeviceFeatures2[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkPhysicalDeviceFeatures2[] ret = new VkPhysicalDeviceFeatures2[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkPhysicalDeviceFeatures2(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkPhysicalDeviceFeatures2 clone(Arena arena, VkPhysicalDeviceFeatures2 src) {
        VkPhysicalDeviceFeatures2 ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkPhysicalDeviceFeatures2[] clone(Arena arena, VkPhysicalDeviceFeatures2[] src) {
        VkPhysicalDeviceFeatures2[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        VkPhysicalDeviceFeatures.LAYOUT.withName("features")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$features = PathElement.groupElement("features");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final StructLayout LAYOUT$features = (StructLayout) LAYOUT.select(PATH$features);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$features = LAYOUT.byteOffset(PATH$features);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$features = LAYOUT$features.byteSize();
}
